SquareGrid

Struct SquareGrid 

pub struct SquareGrid {
    pub size: Size,
    pub layout: SquareLayout,
    pub wrap_flags: WrapFlags,
}

Fields

size: Sizelayout: SquareLayoutwrap_flags: WrapFlags

Implementations

Source

impl SquareGrid

pub const fn new( size: Size, layout: SquareLayout, wrap_flags: WrapFlags, ) -> Self

Creates a new SquareGrid with the specified size, layout, and wrap flags.

pub const fn with_resized_layout(&self, layout_size: [f32; 2]) -> Self

Returns a new SquareGrid with the specified layout size, keeping other properties unchanged.