pub struct Cell(usize);Expand description
Representing a cell or tile in a grid, which is identified by a unique index.
It is a wrapper around a usize index, which uniquely identifies the cell within the grid.
The index is used to access the cell in a flat representation of the grid, such as a 1D array.
Tuple Fields
0: usizeImplementations