Hex

Struct Hex 

pub struct Hex(IVec2);
Hexagonal grid coordinate in axial (cube) coordinate system.

Tuple Fields

0: IVec2

Implementations

Source

impl Hex

pub const HEX_DIRECTIONS: [Self; 6]

Hexagon neighbor coordinates array, following HexOrientation::POINTY_EDGE or HexOrientation::FLAT_EDGE order.

These 6 direction vectors represent the offset from a hex to each of its neighbors. The order corresponds to clockwise directions starting from East (for pointy-top) or NorthEast (for flat-top).

Direction Mapping
IndexPointy-TopFlat-TopVector (Hex)
0EastNE(1, 0)
1SESE(1, -1)
2SWSouth(0, -1)
3WestSW(-1, 0)
4NWNW(-1, 1)
5NENorth(0, 1)
pub const fn new(x: i32, y: i32) -> Self

pub const fn from_offset( offset_coordinate: OffsetCoordinate, orientation: HexOrientation, offset: Offset, ) -> Self

Creates a new Hex from an OffsetCoordinate.

pub const fn x(self) -> i32

pub const fn y(self) -> i32

pub const fn z(self) -> i32

pub const fn into_inner(self) -> IVec2

pub fn to_offset( self, orientation: HexOrientation, offset: Offset, ) -> OffsetCoordinate

Converts a hex coordinate to an offset coordinate.

pub fn neighbor(self, orientation: HexOrientation, direction: Direction) -> Hex

Get the hex at the given direction from self, according to the given orientation is HexOrientation::Pointy or HexOrientation::Flat.

pub const fn length(self) -> i32

Computes coordinates length as a signed integer. The length of a Hex coordinate is equal to its distance from the origin.

pub fn distance_to(self, rhs: Self) -> i32

Computes the distance from self to rhs in hexagonal space as a signed integer.

pub fn hexes_at_distance(self, distance: u32) -> Vec<Hex>

Return a Vec<Hex> containing all Hex which are exactly at a given distance from self. If distance = 0 the Vec<Hex> will be empty.
The number of returned hexes is equal to 6 * distance.

pub fn hexes_in_distance(self, distance: u32) -> Vec<Hex>

Return a Vec<Hex> containing all Hex around self in a given distance, including self.
The number of returned hexes is equal to 3 * distance * (distance + 1) + 1.

pub fn round(fractional_hex: Vec2) -> Self

Rounds floating point coordinates to Hex.