RegionDivideMethod

Enum RegionDivideMethod 

pub enum RegionDivideMethod {
    Pangaea,
    Continent,
    WholeMapRectangle,
    CustomRectangle(Rectangle),
}
Defines the method used to divide regions for civilizations in the game. This enum is used to determine how civilizations are assigned to different regions on the map.

Variants



Pangaea

All civilizations start on the biggest landmass.

This method places all civs on a single, largest landmass.



Continent

Civs are assigned to continents. Any continents with more than one civ are divided.



WholeMapRectangle

This method is primarily used for Archipelago or other maps with many small islands.

The entire map is treated as one large rectangular region. RegionDivideMethod::WholeMapRectangle is equivalent to RegionDivideMethod::CustomRectangle when Rectangle encompasses the entire map area. We will ignore the area ID when method is set to WholeMapRectangle.



CustomRectangle(Rectangle)

Civs start within a custom-defined rectangle.

We will ignore the area ID when method is set to CustomRectangle.