pub struct TechnologyInfo {
pub name: String,
pub cost: u32,
pub row: u8,
pub column: u8,
pub era: String,
pub uniques: Vec<String>,
pub prerequisites: Vec<String>,
pub quote: String,
}Fields
name: Stringcost: u32row: u8The row number of the tech in the tech tree.
It starts at 1. So the total rows which the tech tree has will be the maximum row number.
column: u8era: Stringuniques: Vec<String>prerequisites: Vec<String>quote: StringTrait Implementations
Sourceimpl Debug for TechnologyInfo
impl Debug for TechnologyInfo
Sourceimpl<'de> Deserialize<'de> for TechnologyInfo
impl<'de> Deserialize<'de> for TechnologyInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more